"""
Plot distribution of shiptypes in histograms
Created: 02. April 2018
Author: Marion Aarsnes
"""

# Importing packages
import pandas as pd                 # Read CSV
import seaborn as sns               # Library of plots built upon matplotlib
import matplotlib.pyplot as plt     # Plots
import matplotlib.ticker as mtick   # Formatting plots
import numpy as np                  # Scientific compution
from matplotlib.pyplot import xticks   # Rotate plot

# Read CSV file
AIS_dataframe = pd.read_csv('filedirectory/filename.csv')
print(AIS_dataframe.columns)

# Clean up dataframe
AIS_dataframe = AIS_dataframe[['imo.b', 'shipType.s', 'imo.s', 'length.s', 'length.b', 'bunkeringLength_hrs', 'anchoringLength_hrs', 'bunkeringType', 'confidence_mean']]
AIS_dataframe = AIS_dataframe.rename(columns={"imo.b": "IMO",
                                              "shipType.s": "ShipType",
                                              "imo.s": "IMOship",
                                              "length.s": "ShipLength",
                                              "length.b": "BargeLength",
                                              "anchoringLength_hrs": "AnchoringLengthHrs",
                                              "bunkeringLength_hrs": "BunkeringLengthHrs",
                                              "bunkeringType": "BunkeringType",
                                              "confidence_mean": "ConfMean"})

AIS_dataframe = AIS_dataframe.fillna(value="nan")[AIS_dataframe.ShipType != "nan"]
# Rename ship types
AIS_dataframe = AIS_dataframe.replace({"FSO (Floating, Storage, Offloading)": "FSO", "FPSO (Floating, Production, Storage, Offloading)": "FPSO"})
# Require a minimum confidence mean of 0.7
AIS_dataframe = AIS_dataframe[AIS_dataframe.ConfMean >= 0.7]

# Sett plot style
sns.set(style="whitegrid", color_codes=True)

# Plot number of operations per ship type
ax = sns.countplot(AIS_dataframe.ShipType, order=AIS_dataframe['ShipType'].value_counts().index)
xticks(rotation=90)
plt.show()

# Count number of registered operations per ship type
for shiptype in AIS_dataframe['ShipType'].unique():
    print(shiptype)
    print(AIS_dataframe[AIS_dataframe.ShipType == shiptype]['ShipType'].count())