"""
Plot quantiles and correlation between quantiles (index plot)
Created: 24. May 2018
Author: Marion Aarsnes
"""

# Import packages
import pandas as pd                 # Read CSV
import numpy as np                  # Scientific computation
import matplotlib.pyplot as plt     # Plotting
import matplotlib.ticker as mtick   # Formatting plots
import seaborn as sns               # Library of plots built upon matplotlib

# Set plot style
sns.set(style="whitegrid", color_codes=True)

# Define quantiles
WTquant_0 = 2       # Maximum accepted WT
WTquant_75 = 5.55
PBTquant_0 = 2.1      # Minimum accepted PBT
PBTquant_75 = 10.58

# Plot quantiles
plt.plot(WTquant_0,1,'o',color='r', label='lower bound WT')
plt.plot(WTquant_75,0,'o',color='coral', label='upper bound WT')
plt.plot(PBTquant_0,0,'o',color='b', label='lower bound PBT')
plt.plot(PBTquant_75,1,'o',color='lightblue', label='upper bound PBT')
plt.title('Quantile plot')
plt.xlabel('Time [hours]')
plt.ylabel('Score')
plt.legend()
plt.show()

# Plot linearised relationship between quantiles
plt.plot(WTquant_0,1,'o',color='r')
plt.plot(WTquant_75,0,'o',color='r')
plt.plot(PBTquant_0,0,'o',color='b')
plt.plot(PBTquant_75,1,'o',color='b')
plt.plot([0,WTquant_0],[1,1], '-', color='r')
plt.plot([WTquant_0,WTquant_75],[1,0], '-', color='r', label='WT')
plt.plot([WTquant_75,15],[0,0], '-', color='r')
plt.plot([0,PBTquant_0],[0,0], '-', color='b')
plt.plot([PBTquant_0,PBTquant_75],[0,1], '-', color='b', label='PBT')
plt.plot([PBTquant_75,15],[1,1], '-', color='b')
plt.title('Index plot')
plt.xlabel('Time [hours]')
plt.ylabel('TW/TPBT')
plt.xlim(0,12)
plt.legend()
plt.show()